@@ -11,8 +11,8 @@
 using namespace PlasmaVault;
 
 VaultsModel::Private::Private(VaultsModel *parent)
-    : service("org.kde.kded5", "/modules/plasmavault", QDBusConnection::sessionBus())
-    , serviceWatcher("org.kde.kded5", QDBusConnection::sessionBus())
+    : service("org.kde.kded6", "/modules/plasmavault", QDBusConnection::sessionBus())
+    , serviceWatcher("org.kde.kded6", QDBusConnection::sessionBus())
     , q(parent)
 {
     connect(&service, &org::kde::plasmavault::vaultAdded, this, &Private::onVaultAdded);
@@ -22,7 +22,7 @@ VaultsModel::Private::Private(VaultsModel *parent)
     connect(&serviceWatcher, &QDBusServiceWatcher::serviceOwnerChanged, this, [this](const QString &service, const QString &oldOwner, const QString &newOwner) {
         Q_UNUSED(oldOwner);
 
-        if (service != "org.kde.kded5") {
+        if (service != "org.kde.kded6") {
             return;
         }
 
@@ -361,11 +361,7 @@ bool SortedVaultsModelProxy::lessThan(const QModelIndex &left, const QModelIndex
 {
     const auto leftData = sourceModel()->data(left, VaultsModel::VaultName);
     const auto rightData = sourceModel()->data(right, VaultsModel::VaultName);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    return leftData < rightData;
-#else
     return QPartialOrdering::Less == QVariant::compare(leftData, rightData);
-#endif
 }
 
 bool SortedVaultsModelProxy::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
@@ -388,3 +384,7 @@ void SortedVaultsModelProxy::reloadDevices()
 {
     static_cast<VaultsModel *>(sourceModel())->reloadDevices();
 }
+
+#include "moc_vaultsmodel_p.cpp"
+
+#include "moc_vaultsmodel.cpp"
